@@ -104,9 +104,10 @@ def generate_client_config():
     save_to_file = prompt("Save settings to file?", default='y', type=click.BOOL, show_choices=True)
 
     if save_to_file:
-        with open(api_settings.NETSUITE_CREDENTIALS_PATH, 'wb+') as f:
-            f.write(json.dumps(creds, indent=4))
-            print(f"Netsuite Credentials written to: {api_settings.NETSUITE_CREDENTIALS_PATH}")
+        with open(api_settings.CREDENTIALS_PATH, 'w') as f:
+            creds_json = json.dumps(creds, indent=4)
+            f.write(creds_json)
+            print(f"Netsuite Credentials written to: {api_settings.CREDENTIALS_PATH}")
     else:
         click.echo(creds)
 
